/**
 * <copyright>
 * 
 * Copyright (c) 2009-2010 Thales Corporate Services S.A.S.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 * Thales Corporate Services S.A.S - initial API and implementation
 * 
 * </copyright>
 */

package org.eclipse.egf.pattern.strategy.domaindriven;

import java.io.File;
import java.util.List;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.egf.model.pattern.Pattern;
import org.eclipse.egf.pattern.EGFPatternPlugin;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.util.EcoreUtil;

/**
 * TODO: improve pattern selection: At present time, the selection is done via
 * type matching. We can imagine a custom matching policy (for example a pattern
 * can apply if and only if the model element is named 'toto')
 * 
 * This is the default implementation. It supports built-in domain kinds.
 * 
 * @author Thomas Guiu
 * 
 */
public class DefaultDomainVisitor extends AbstractDomainVisitor {

    public Object[] getChildren(Object model) {
        // a implementer par les users en fct du model
        if (model instanceof EObject)
            return ((EObject) model).eContents().toArray();
        if (model instanceof List<?>)
            return ((List<?>) model).toArray();
        if (model instanceof File)
            return ((File) model).listFiles();
        if (model instanceof IContainer) {

            try {
                return ((IContainer) model).members();
            } catch (CoreException e) {
                EGFPatternPlugin.getDefault().logError(e);
            }
        }
        return EMPTY_ARRAY;
    }

    @Override
    protected List<Pattern> findPatterns(Object model) {
        if (model instanceof EObject) {
            String fullName = EcoreUtil.getURI(((EObject) model).eClass()).toString();
            return type2patterns.get(fullName);
        }

        return super.findPatterns(model);
    }
}
